@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _FILEANALYZER_H_
-#define _FILEANALYZER_H_
+#ifndef FILEANALYZER_H
+#define FILEANALYZER_H
 
 #include <QList>
 #include <QMutex>
@@ -48,11 +48,11 @@ class FileAnalyzer : public Analyzer
 public:
     explicit FileAnalyzer(LogMode *logMode);
 
-    virtual ~FileAnalyzer();
+    ~FileAnalyzer() override;
 
-    void watchLogFiles(bool enabled) Q_DECL_OVERRIDE;
+    void watchLogFiles(bool enabled) override;
 
-    void setLogFiles(const QList<LogFile> &logFiles) Q_DECL_OVERRIDE;
+    void setLogFiles(const QList<LogFile> &logFiles) override;
 
 protected:
     virtual LogFileReader *createLogFileReader(const LogFile &logFile) = 0;
@@ -75,7 +75,7 @@ private:
      */
     bool insertLine(const QString &buffer, const LogFile &originalFile, ReadingMode readingMode);
 
-private slots:
+private Q_SLOTS:
     void logFileChanged(LogFileReader *logFileReader, Analyzer::ReadingMode readingMode,
                         const QStringList &content);
 
@@ -83,4 +83,4 @@ protected:
     QList<LogFileReader *> logFileReaders;
 };
 
-#endif // _FILEANALYZER_H_
+#endif // _FILEANALYZER_H
