@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _MULTIPLE_FILE_LIST_H_
-#define _MULTIPLE_FILE_LIST_H_
+#ifndef MULTIPLE_FILE_LIST_H
+#define MULTIPLE_FILE_LIST_H
 
 #include <QButtonGroup>
 #include <QWidget>
@@ -47,13 +47,13 @@ public:
 
     int addCategory(const QString &itemName, const QString &buttonName);
 
-public slots:
+public Q_SLOTS:
     void removeAllItems();
 
-signals:
+Q_SIGNALS:
     void fileListChanged();
 
-private slots:
+private Q_SLOTS:
 
     void updateButtons();
 
@@ -61,7 +61,7 @@ private slots:
     void moveUpItem();
     void moveDownItem();
 
-protected slots:
+protected Q_SLOTS:
     virtual void addItem(int category);
 
     void modifyItem();
@@ -92,4 +92,4 @@ private:
     bool missingFiles;
 };
 
-#endif //_MULTIPLE_FILE_LIST_H_
+#endif //_MULTIPLE_FILE_LIST_H
